@@ -86,6 +86,8 @@ ARABIC_K = (
     'iltisak',
     'infilak',
     'istimlak',
+    'istihkak',
+    'iştikak',
     'iştirak',
     'ittifak',
     'memluk',
@@ -143,6 +145,7 @@ MAJOR_HAMONY_EXCEPTIONS = (
     'kabul',
     'kalp',
     'kanaat',
+    'kabahat',
     'kapital',
     'karambol',
     'katedral',
