@@ -122,13 +122,14 @@ def soften(parameter_word, proper_noun=False, negative=False):
 
     if proper_noun:
         word += '\''
-
-    if 'discontinuous_hard_consonant' in actual_last_letter and not proper_noun:
+    elif 'discontinuous_hard_consonant' in actual_last_letter:
         if actual_last_vowel['vowel_count'] > 1:
-            word = concat(
-                word[0:len(word) - 1],
-                actual_last_letter['soften_consonant']
-            )
+            if word not in consonants.ARABIC_K or actual_last_letter.get('letter') != 'k':
+                if word in consonants.ARABIC_T or actual_last_letter.get('letter') != 't':
+                    word = concat(
+                        word[0:len(word) - 1],
+                        actual_last_letter['soften_consonant']
+                    )
 
     return word
 
